@@ -21,6 +21,7 @@
 #ifndef PLASMAVAULT_KDED_ENGINE_BACKEND_P_H
 #define PLASMAVAULT_KDED_ENGINE_BACKEND_P_H
 
+#include <QDir>
 #include <QList>
 #include <QString>
 #include <QStringList>
@@ -47,6 +48,11 @@ public:
                                       const MountPoint &mountPoint,
                                       const Vault::Payload &payload) = 0;
 
+    virtual FutureResult<> import(const QString &name,
+                                  const Device &device,
+                                  const MountPoint &mountPoint,
+                                  const Vault::Payload &payload) = 0;
+
     virtual FutureResult<> open(const Device &device,
                                 const MountPoint &mountPoint,
                                 const Vault::Payload &payload) = 0;
@@ -70,8 +76,15 @@ public:
             const QString &command,
             const QPair<bool, QString> &result) const;
 
-protected:
-    static bool isDirectoryEmpty(const QString &path);
+    static inline bool directoryExists(const QString &path)
+    {
+        QDir dir(path);
+
+        if (!dir.exists()) return false;
+
+        return !dir.entryList(QDir::NoDotAndDotDot | QDir::AllEntries)
+                    .isEmpty();
+    }
 
 };
 
