@@ -1,5 +1,5 @@
 /*
- *   Copyright 2017 by Ivan Cukic <ivan.cukic (at) kde.org>
+ *   Copyright 2017, 2018, 2019 by Ivan Cukic <ivan.cukic (at) kde.org>
  *
  *   This program is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU General Public License as
@@ -62,6 +62,23 @@ public:
     KSharedConfigPtr config;
     Device device;
 
+    FILE* deviceDirectoryLock = nullptr;
+
+    void lockDeviceDirectory()
+    {
+        if (!deviceDirectoryLock) {
+            deviceDirectoryLock = fopen(device.data().toLocal8Bit().data(), "r");
+        }
+    }
+
+    void unlockDeviceDirectory()
+    {
+        if (deviceDirectoryLock) {
+            fclose(deviceDirectoryLock);
+            deviceDirectoryLock = nullptr;
+        }
+    }
+
     QTimer savingDelay;
 
 
@@ -161,10 +178,13 @@ public:
                 emit q->statusChanged(data->status = VaultInfo::Dismantled);
 
             } else {
+                QDir deviceDir(device.data());
+
                 const auto newStatus =
-                               isOpened()      ? VaultInfo::Opened :
-                               isInitialized() ? VaultInfo::Closed :
-                                                 VaultInfo::NotInitialized;
+                               !deviceDir.exists() ? VaultInfo::DeviceMissing :
+                               isOpened()          ? VaultInfo::Opened :
+                               isInitialized()     ? VaultInfo::Closed :
+                                                     VaultInfo::NotInitialized;
 
                 if (oldStatus == newStatus) return;
 
@@ -204,6 +224,12 @@ public:
 
             emit q->statusChanged(VaultInfo::Error);
         }
+
+        if (data && data->status == VaultInfo::Opened) {
+            lockDeviceDirectory();
+        } else {
+            unlockDeviceDirectory();
+        }
     }
 
 
@@ -246,8 +272,7 @@ public:
         const QString actualMountPoint = vaultData.mountPoint.data();
         vaultConfig.writeEntry(CFG_MOUNT_POINT, actualMountPoint);
 
-        const QDir mountPointDir(vaultData.mountPoint);
-
+        const QDir mountPointDir(vaultData.mountPoint.data());
 
         return
             // If the backend is not known, we need to fail
@@ -261,7 +286,7 @@ public:
                           i18n("Mount point is not specified")) :
 
             // Lets try to create the mount point
-            !mountPointDir.exists() && !QDir().mkpath(vaultData.mountPoint) ?
+            !mountPointDir.exists() && !QDir().mkpath(vaultData.mountPoint.data()) ?
                 errorData(Error::MountPointError,
                           i18n("Cannot create the mount point")) :
 
@@ -287,6 +312,13 @@ public:
 
 
 
+    ~Private()
+    {
+        unlockDeviceDirectory();
+    }
+
+
+
     template <typename T>
     T followFuture(VaultInfo::Status whileNotFinished, const T &future)
     {
@@ -470,7 +502,7 @@ FutureResult<> Vault::close()
                 } else {
                     // We want to check whether there is an application
                     // that is accessing the vault
-                    AsynQt::Process::getOutput(QStringLiteral("lsof"), { QStringLiteral("-t"), mountPoint() })
+                    AsynQt::Process::getOutput(QStringLiteral("lsof"), { QStringLiteral("-t"), mountPoint().data() })
                         | cast<QString>()
                         | onError([this] {
                             d->updateMessage(i18n("Unable to close the vault, an application is using it"));
@@ -528,7 +560,7 @@ FutureResult<> Vault::forceClose()
     using namespace AsynQt::operators;
 
     AsynQt::await(
-        AsynQt::Process::getOutput(QStringLiteral("lsof"), { QStringLiteral("-t"), mountPoint() })
+        AsynQt::Process::getOutput(QStringLiteral("lsof"), { QStringLiteral("-t"), mountPoint().data() })
             | cast<QString>()
             | onError([this] {
                 d->updateMessage(i18n("Failed to fetch the list of applications using this vault"));
@@ -651,7 +683,7 @@ MountPoint Vault::mountPoint() const
 
 void Vault::setMountPoint(const MountPoint &mountPoint)
 {
-    if (d->data->mountPoint != mountPoint.data()) {
+    if (d->data->mountPoint.data() != mountPoint.data()) {
         QDir().rmpath(d->data->mountPoint.data());
         QDir().mkpath(mountPoint.data());
 
@@ -735,7 +767,7 @@ VaultInfo Vault::info() const
 {
     VaultInfo vaultInfo;
 
-    vaultInfo.device        = device();
+    vaultInfo.device        = device().data();
     vaultInfo.name          = name();
 
     vaultInfo.status        = status();
@@ -747,6 +779,14 @@ VaultInfo Vault::info() const
     return vaultInfo;
 }
 
+
+
+void Vault::updateStatus()
+{
+    d->updateStatus();
+}
+
+
 } // namespace PlasmaVault
 
 
